@@ -580,7 +580,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
                 self.model = model
 
             def predict(self, X):
-                return self.model.predict(X, context=self.context).values
+                return self.model.predict(X).values
             
         dask_component_graph = ParallelPostFit(avm_wrapper(model))
         return dask_component_graph.predict(X) 
